PdgError

Enum PdgError 

pub enum PdgError {
    SqliteError(Error),
    Io(Error),
    CacheDirectoryUnavailable,
    OfflineDatabaseMissing(PathBuf),
    Download(String),
    DatabaseSizeMismatch {
        path: PathBuf,
        expected: u64,
        actual: u64,
    },
    DatabaseChecksumMismatch {
        path: PathBuf,
        expected: &'static str,
        actual: String,
    },
    ParseValueType(String),
    ParseLimitType(String),
    ParseDataType(String),
    QuantumNumberConversion(QuantumNumberConversionError),
    Custom(String),
}
Errors returned by database access, code parsing, and quantum number conversion.

Variants



SqliteError(Error)

A SQLite error from the PDG database.



Io(Error)

An I/O error occurred while reading, writing, or caching the PDG database.



CacheDirectoryUnavailable

No OS-specific cache directory could be found.



OfflineDatabaseMissing(PathBuf)

The PDG database is not cached and network access is disabled.



Download(String)

Downloading the PDG database failed.



DatabaseSizeMismatch

A cached or downloaded PDG database has the wrong byte length.

Fields

path: PathBuf

Path to the database file that was checked.

expected: u64

Expected byte length.

actual: u64

Actual byte length.



DatabaseChecksumMismatch

A cached or downloaded PDG database has the wrong SHA-256 digest.

Fields

path: PathBuf

Path to the database file that was checked.

expected: &'static str

Expected SHA-256 digest.

actual: String

Actual SHA-256 digest.



ParseValueType(String)

A value type code was not recognized.



ParseLimitType(String)

A limit type code was not recognized.



ParseDataType(String)

A data type code was not recognized.



QuantumNumberConversion(QuantumNumberConversionError)

A quantum number could not be converted into the requested numeric representation.



Custom(String)

An application-specific error message.