BranchingFraction

Struct BranchingFraction 

pub struct BranchingFraction<'pdg> {
    pub pdgid: PdgId,
    pub description: String,
    pub mode_number: Option<u32>,
    pub value: DataEntry<'pdg>,
    pub kind: BranchingFractionKind,
    pub products: Vec<DecayProduct<'pdg>>,
    pub related_data: Vec<RelatedDataEntry<'pdg>>,
}
Branching-fraction data for a particle decay mode.

Fields

pdgid: PdgId

PDG identifier for the branching-fraction row.

description: String

Human-readable decay description.

mode_number: Option<u32>

PDG mode number, when available.

value: DataEntry<'pdg>

Numeric value for the branching fraction.

kind: BranchingFractionKind

Exclusive or inclusive branching-fraction kind.

products: Vec<DecayProduct<'pdg>>

Decay products attached to the branching-fraction row.

related_data: Vec<RelatedDataEntry<'pdg>>

Other data rows mapped to this branching-fraction row.

Implementations

Source

impl BranchingFraction<'_>

pub fn measurements(&self) -> PdgResult<Vec<PdgMeasurement>>

Loads measurements supporting this branching fraction.

Errors

Returns a database error if the measurement query fails.

pub fn footnotes(&self) -> PdgResult<Vec<PdgFootnote>>

Loads footnotes attached to this branching fraction.

Errors

Returns a database error if the footnote query fails.

pub fn texts(&self) -> PdgResult<Vec<PdgText>>

Loads text blocks attached to this branching fraction.

Errors

Returns a database error if the text query fails.