DecayProduct

Struct DecayProduct 

pub struct DecayProduct<'pdg> {
    pub name: String,
    pub is_outgoing: bool,
    pub multiplier: i64,
    /* private fields */
}
Decay product listed for a branching-fraction row.

Fields

name: String

PDG item name for the product.

is_outgoing: bool

Whether this product is outgoing from the decay.

multiplier: i64

Multiplicity of this product in the decay row.

Implementations

Source

impl<'pdg> DecayProduct<'pdg>

pub fn item(&self) -> PdgResult<Option<PdgItem<'pdg>>>

Loads the PDG item for this decay product.

Errors

Returns a database error if the item query fails.

pub fn particle(&self) -> PdgResult<Option<PdgParticle<'pdg>>>

Loads the particle for this decay product, when it names a particle.

Errors

Returns a database error if the particle query fails.

pub fn children(&self) -> PdgResult<Vec<PdgItemChild<'pdg>>>

Loads child items for this decay product name.

Errors

Returns a database error if the hierarchy query fails.

pub fn parents(&self) -> PdgResult<Vec<PdgItem<'pdg>>>

Loads parent items for this decay product name.

Errors

Returns a database error if the hierarchy query fails.