pub struct DecayProduct<'pdg> {
pub name: String,
pub is_outgoing: bool,
pub multiplier: i64,
/* private fields */
}Expand description
Decay product listed for a branching-fraction row.
Fields
name: StringPDG item name for the product.
is_outgoing: boolWhether this product is outgoing from the decay.
multiplier: i64Multiplicity of this product in the decay row.
Implementations
Sourceimpl<'pdg> DecayProduct<'pdg>
impl<'pdg> DecayProduct<'pdg>
Sourcepub fn item(&self) -> PdgResult<Option<PdgItem<'pdg>>>
pub fn item(&self) -> PdgResult<Option<PdgItem<'pdg>>>
Loads the PDG item for this decay product.
Errors
Returns a database error if the item query fails.
Sourcepub fn particle(&self) -> PdgResult<Option<PdgParticle<'pdg>>>
pub fn particle(&self) -> PdgResult<Option<PdgParticle<'pdg>>>
Loads the particle for this decay product, when it names a particle.
Errors
Returns a database error if the particle query fails.